==> openGion6.9.7.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2017/07/18 08:42:12                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , DROLE        varchar           (  20 )                   NOT NULL            /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          varchar           (  30 )                   NOT NULL            /*  30 項目     */
 , CVALUE       varchar           ( 200 )                   NOT NULL            /*  40 値       */
 , VALCDTN      varchar           (  10 )                   NOT NULL            /*  50 条件     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員 */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者   */
);

==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , DROLE        varchar           (  20 )                   NOT NULL            /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          varchar           (  30 )                   NOT NULL            /*  30 項目     */
 , CVALUE       varchar           ( 200 )                   NOT NULL            /*  40 値       */
 , VALCDTN      varchar           (  10 )                   NOT NULL            /*  50 条件     */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET       varchar           (  10 )                                       /* 850 作成者   */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者   */
);
